@@ -1401,7 +1401,7 @@ class Sequence(Generic[T], Iterable[T]):
         return self.skip(n).first( )
     
 
-    def windowed(self, size: int, step: int = 1, partialWindows: bool = False) -> Sequence[Sequence[T]]:
+    def windowed(self, size: int, step: int = 1, partialWindows: bool = False) -> Sequence[List[T]]:
         """
          Returns a Sequence of all possible sliding windows of size [size] from the given Sequence.
 
@@ -1423,7 +1423,7 @@ class Sequence(Generic[T], Iterable[T]):
         return WindowedSequence(self, size, step, partialWindows)
     
 
-    def chunked(self, size: int) -> Sequence[Sequence[T]]:
+    def chunked(self, size: int) -> Sequence[List[T]]:
         """
          Returns a Sequence of all possible chunks of size [size] from the given Sequence.
 
@@ -1466,7 +1466,7 @@ class Sequence(Generic[T], Iterable[T]):
         """
         return separator.join(self)
     
-    def progress(self, progress_func: Callable[[Sequence[T]], Iterable[T]]) -> Sequence[T]:
+    def progress(self, progress_func: Callable[[Iterable[T]], Iterable[T]]) -> Sequence[T]:
         """
          Returns a Sequence that enable a progress bar for the given Sequence.
         
